@@ -15,3 +15,10 @@
 #undef UNIX
 #undef HAVE_LDAP
 #undef HAVE_MYSQL
+#undef GDA_MAJOR
+#undef GDA_MINOR
+#undef GDA_PATCHLEVEL
+/*
+ * Backward compatibility
+ */
+#undef HAVE_GDA
