@@ -141,7 +141,13 @@ gda_command_set_connection(Gda_Command* cmd, Gda_Connection* cnc)
   CORBA_exception_init(&ev);
   
   cmd->command = GDA_Connection_createCommand(cnc->connection, &ev);
-  return Exception(&ev);
+  if (Exception(&ev) < 0)
+    {
+      cmd->connection = 0;
+      return -1;
+    }
+  cmd->connection->commands = g_list_append(cmd->connection->commands, cmd);
+  return 0;
 }
   
 
@@ -203,6 +209,53 @@ gda_command_get_text(Gda_Command* cmd)
   return cmd->text;
 }
 
+
+#define ENUM_TO_STR(e) case (e): strncpy(bfr, #e, length); break
+static gchar* 
+gda_gdatype_2_string(gchar* bfr, gint length, GDA_ValueType t)
+{
+  if (!bfr)
+    {
+      bfr = g_new0(gchar, 20);
+      length = 20;
+    }
+  switch (t)
+    {
+      ENUM_TO_STR(GDA_TypeNull);
+      ENUM_TO_STR(GDA_TypeBigint);
+      ENUM_TO_STR(GDA_TypeBinary);
+      ENUM_TO_STR(GDA_TypeBoolean);
+      ENUM_TO_STR(GDA_TypeBstr);
+      ENUM_TO_STR(GDA_TypeChar);
+      ENUM_TO_STR(GDA_TypeCurrency);
+      ENUM_TO_STR(GDA_TypeDate);
+      ENUM_TO_STR(GDA_TypeDbDate);
+      ENUM_TO_STR(GDA_TypeDbTime);
+      ENUM_TO_STR(GDA_TypeDbTimestamp);
+      ENUM_TO_STR(GDA_TypeDecimal);
+      ENUM_TO_STR(GDA_TypeDouble);
+      ENUM_TO_STR(GDA_TypeError);
+      ENUM_TO_STR(GDA_TypeInteger);
+      ENUM_TO_STR(GDA_TypeLongvarbin);
+      ENUM_TO_STR(GDA_TypeLongvarchar);
+      ENUM_TO_STR(GDA_TypeLongvarwchar);
+      ENUM_TO_STR(GDA_TypeNumeric);
+      ENUM_TO_STR(GDA_TypeSingle);
+      ENUM_TO_STR(GDA_TypeSmallint);
+      ENUM_TO_STR(GDA_TypeTinyint);
+      ENUM_TO_STR(GDA_TypeUBigint);
+      ENUM_TO_STR(GDA_TypeUSmallint);
+      ENUM_TO_STR(GDA_TypeVarchar);
+      ENUM_TO_STR(GDA_TypeVarbin);
+      ENUM_TO_STR(GDA_TypeVarwchar);
+      ENUM_TO_STR(GDA_TypeFixchar);
+      ENUM_TO_STR(GDA_TypeFixbin);
+      ENUM_TO_STR(GDA_TypeFixwchar);
+    }
+  return bfr;
+}
+
+
 /**
  * gda_command_execute:
  * @cmd: the command object
@@ -238,6 +291,7 @@ gda_command_execute(Gda_Command* cmd, gulong* reccount, gulong flags)
   GList*                    ptr;
   GDA_CmdParameter*         corba_parameter;
   gint                      idx;
+  GDA_RowAttributes*        field_attributes;
   
   g_return_val_if_fail(cmd != NULL, 0);
   g_return_val_if_fail(cmd->text != NULL, 0);
@@ -284,20 +338,38 @@ gda_command_execute(Gda_Command* cmd, gulong* reccount, gulong flags)
 	  idx++;
 	}
     }
-        
-  corba_rs = GDA_Command_execute(cmd->command, cmd->text, (CORBA_long*)&corba_reccount, corba_parameters,
-				 flags, &ev);
+  fprintf(stderr,"gda_command_execute: calling GDA_Command_execute\n");
+  corba_rs = GDA_Command_execute(cmd->command, cmd->text, (CORBA_long*)&corba_reccount,
+				 corba_parameters, flags, &ev);
+  fprintf(stderr,"gda_command_execute: GDA_Command_execute returns %p\n", corba_rs);
   if (!corba_rs)
     return 0;
   *reccount = corba_reccount;
   if (Exception(&ev) < 0)
     return 0;
   rs = gda_recordset_new();
-  rs->cmd = cmd;
+  rs->external_cmd = cmd;
   rs->corba_rs = corba_rs;
   rs->eof = 0;
   rs->bof = 0;
   rs->open = 1;
+
+  field_attributes = GDA_Recordset_describe(corba_rs, &ev);
+  if (Exception(&ev) || field_attributes == CORBA_OBJECT_NIL)
+    {
+      fprintf(stderr," cannot get row description\n");
+    }
+  for (idx = 0; idx  < field_attributes->_length; idx++)
+    {
+      gchar type_bfr[120];
+      fprintf(stderr,"Description for field '%s'\n", field_attributes->_buffer[idx].name);
+      fprintf(stderr,"     defined Size   = %d\n", field_attributes->_buffer[idx].definedSize);
+      fprintf(stderr,"     scale          = %d\n", field_attributes->_buffer[idx].scale);
+      fprintf(stderr,"     gdaType        = '%s'\n", gda_gdatype_2_string(type_bfr, sizeof(type_bfr),
+									    field_attributes->_buffer[idx].gdaType));
+      fprintf(stderr,"     cType          = %d\n", field_attributes->_buffer[idx].cType);
+      fprintf(stderr,"     nativeType     = %d\n", field_attributes->_buffer[idx].nativeType);
+    }
   return rs;
 }
 
