@@ -114,7 +114,7 @@ gda_stringify_value(gchar* bfr, gint maxlen, GDA_Field* f)
 	if (GDA_FIELD_BOOLEAN(f))
 	  retstr = _("TRUE");
 	else
-	  retstr = _("FLASE");
+	  retstr = _("FALSE");
 	if (bfr)
 	  retval = strncpy(bfr, retstr, maxlen);
 	else
