@@ -54,6 +54,21 @@ Exception(CORBA_Environment *ev)
 }
 
 
+static void
+free_chunks(GList* chunks)
+{
+  GDA_Row* row;
+  GList*   ptr;
+
+  ptr = chunks;
+  while(ptr)
+    {
+      row = ptr->data;
+      CORBA_free(row);
+      ptr = g_list_next(ptr);
+    }
+}
+
 __inline__ static GDA_Row*
 row_by_idx(Gda_Recordset* rs, gint idx)
 {
@@ -110,9 +125,9 @@ gda_recordset_free(Gda_Recordset* rs)
 {
   if (rs->open)
     gda_recordset_close(rs);
-  if (rs->cmd)
+  if (rs->internal_cmd)
     {
-      gda_command_free(rs->cmd);
+      gda_command_free(rs->internal_cmd);
     }
   g_free(rs);
 }
@@ -132,14 +147,24 @@ gda_recordset_free(Gda_Recordset* rs)
 void
 gda_recordset_close(Gda_Recordset* rs)
 {
+  CORBA_Environment ev;
+
+  CORBA_exception_init(&ev);
+  
   if (!rs->open)
     return;
   rs->open = 0;
   if (rs->corba_rs)
-    g_warning("NOT shutting down CORBA recordset");
+    {
+      fprintf(stderr,"Closing Recordset in the server\n");
+      GDA_Recordset_close(rs->corba_rs, &ev);
+      Exception(&ev);
+    }
   rs->corba_rs = CORBA_OBJECT_NIL;
   if (rs->chunks)
-    g_warning("gda_recordset_close: Leaking memory, not freeing data rows");
+    {
+      free_chunks(rs->chunks);
+    }
   rs->chunks = 0;
 }
 
