@@ -20,7 +20,7 @@ gda_mysql_recset_free(Gda_MYSQL_Recordset* rs)
 gint
 gda_MYSQL_recset_close(Gda_MYSQL_Recordset* rs)
 {
-  ;
+  return 0;
 }
 
 
