@@ -234,27 +234,26 @@ static GDA_Recordset_Chunk*
 gda_mysql_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environment* ev)
 {
 
+  GDARecordset_Servant* recset_servant = (GDARecordset_Servant*)_obj;
+  Gda_MYSQL_Recordset*  rs = recset_servant->recset;
+  GDA_Row*              row;
+  gint                  rowidx;
+  GDA_Recordset_Chunk*  chunk;
+  GDA_Field*            field;
+
+  chunk = GDA_Recordset_Chunk__alloc();
+  chunk->_buffer = CORBA_sequence_GDA_Row_allocbuf(count);
+  chunk->_length = 0;
+  for (rowidx = 0; rowidx < count; rowidx++)
+    {
+      chunk->_buffer[rowidx]._length = 0;
+      chunk->_buffer[rowidx]._buffer = 0;
+    }
+  rowidx = 0;
+
   return 0;
 }
 
-CORBA_Object
-mysql_connection_factory__create  (PortableServer_POA poa,   gpointer *impl_ptr,  CORBA_Environment *ev)
-{
-  GDAConnectionFactory_Servant* servant;
-  PortableServer_ObjectId *objid;
-  CORBA_Object retval;
-  servant = g_new0(GDAConnectionFactory_Servant, 1);
-  servant->base._private = NULL;
-  servant->base.vepv     = &poa_gda_connectionfactory__vepv;
-  servant->poa           = poa;
-  POA_GDA_ConnectionFactory__init((PortableServer_Servant)servant, ev);
-  objid = PortableServer_POA_activate_object(poa, servant, ev);
-  CORBA_free(objid);
-  Exception(ev);
-  retval =  PortableServer_POA_servant_to_reference(poa, (PortableServer_Servant)servant, ev);
-  *impl_ptr = servant;
-  return retval;
-}
 
 GDA_Connection_DSNlist*
 gda_mysql_Connection_listSources(PortableServer_Servant _obj,
@@ -300,9 +299,27 @@ gda_mysql_Connection_listSources(PortableServer_Servant _obj,
 
       
   
+CORBA_Object
+gda_mysql_connection_factory__create  (PortableServer_POA poa,   gpointer *impl_ptr,  CORBA_Environment *ev)
+{
+  GDAConnectionFactory_Servant* servant;
+  PortableServer_ObjectId *objid;
+  CORBA_Object retval;
+  servant = g_new0(GDAConnectionFactory_Servant, 1);
+  servant->base._private = NULL;
+  servant->base.vepv     = &poa_gda_connectionfactory__vepv;
+  servant->poa           = poa;
+  POA_GDA_ConnectionFactory__init((PortableServer_Servant)servant, ev);
+  objid = PortableServer_POA_activate_object(poa, servant, ev);
+  CORBA_free(objid);
+  Exception(ev);
+  retval =  PortableServer_POA_servant_to_reference(poa, (PortableServer_Servant)servant, ev);
+  *impl_ptr = servant;
+  return retval;
+}
 
 void
-mysql_connection_factory__destroy (PortableServer_POA poa,   gpointer impl_ptr,   CORBA_Environment *ev)
+gda_mysql_connection_factory__destroy (PortableServer_POA poa,   gpointer impl_ptr,   CORBA_Environment *ev)
 {
   ;
 }
