@@ -64,7 +64,7 @@ main(int argc, char* argv[])
   root_poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(orb, "RootPOA", ev);
   Exception(ev);
   
-  connection_factory_obj = mysql_connection_factory__create(root_poa, &servant, ev);
+  connection_factory_obj = gda_mysql_connection_factory__create(root_poa, &servant, ev);
   
   Exception(ev);
   objref                 = CORBA_ORB_object_to_string(orb, connection_factory_obj, ev);
