@@ -65,7 +65,7 @@ gda_odbc_cmd_set_connection(Gda_ODBC_Command* cmd,
 			    Gda_ODBC_Connection* cnc)
 {
   Gda_ODBC_Connection* rc = cmd->cnc;
-
+  fprintf(stderr,"gda_odbc_cmd_set_connection: cmd = %p, connection = %p\n", cmd, cnc);
   cmd->cnc = cnc;
   return rc;
 }
@@ -344,10 +344,11 @@ gda_odbc_init_recset_for_hstmt(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
   rec->at_begin = 1;
   rec->pos = 0;
 
-  fprintf(stderr,"gda_init_recset_for_hstmt: entered, recset = 0x%p\n", rec);
+  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: entered, recset = 0x%p\n", rec);
+  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: entered, recset->hstmt = 0x%p\n", rec->hstmt);
   rc = SQLNumResultCols(rec->hstmt, &ncols);
-  fprintf(stderr,"gda_init_recset_for_hstmt: number of columns: rc = %d, ncols = %d\n", rc, ncols);
-  if (rc == SQL_ERROR)
+  fprintf(stderr,"gda_odbc_init_recset_for_hstmt: number of columns: rc = %d, ncols = %d\n", rc, ncols);
+  if (rc != SQL_SUCCESS)
     {
       gda_odbc_error_make(e, rec, rec->cmd->cnc , "SQLNumResultCols");
       g_log("GDA ODBC", G_LOG_LEVEL_DEBUG, "SQLNumResultCols error\n");
@@ -377,7 +378,7 @@ gda_odbc_init_recset_for_hstmt(Gda_ODBC_Recordset* rec, Gda_ODBC_Error* e)
 	}
       colname[colnamelen] = '\0';
       f->name = g_strdup(colname);
-      fprintf(stderr,"gda_init_recset_for_hstmt: describing field '%s'\n", f->name);
+      fprintf(stderr,"gda_odbc_init_recset_for_hstmt: describing field '%s'\n", f->name);
       rec->fields = g_list_append(rec->fields, f);
     }
   return rec;
@@ -399,16 +400,22 @@ gda_odbc_cmd_execute(Gda_ODBC_Command* cmd, Gda_ODBC_Error* error, const GDA_Cmd
   GDA_CmdParameter*      current_parameter;
 
   recset = gda_odbc_recset_new();
+  recset->hstmt = 0;
   fprintf(stderr,"gda_odbc_cmd_execute: enter\n");
-
+  fprintf(stderr,"gda_odbc_cmd_execute: cmd = %p\n", cmd);
+  fprintf(stderr,"gda_odbc_cmd_execute: cmd->cnc = %p\n", cmd->cnc);
+  fprintf(stderr,"gda_odbc_cmd_execute: cmd->cnd->hdbc = %p\n", cmd->cnc->hdbc);
+  
   rc = SQLAllocStmt(cmd->cnc->hdbc, &recset->hstmt);
-
-  if (rc == SQL_ERROR)
+  
+  if (rc != SQL_SUCCESS)
     {
-      gda_odbc_error_make(error, recset, cmd->cnc, "SQLAllocStmt");
+      fprintf(stderr,"gda_odbc_cmd_execute: SQLAllocStmt: hstmt is now %p\n", recset->hstmt);
+      gda_odbc_error_make(error, 0, cmd->cnc, "SQLAllocStmt");
       gda_odbc_recset_free(recset);
       return 0;
     }
+  fprintf(stderr,"gda_odbc_cmd_execute: recset->hstmt = %p\n", recset->hstmt);
 #if 0
   rc = SQLSetScrollOptions(recset->hstmt, SQL_CONCUR_ROWVER,  SQL_SCROLL_KEYSET_DRIVEN, 20);
   if (rc != SQL_SUCCESS)
