@@ -92,15 +92,20 @@ schema_tables(Gda_ODBC_Recordset*   recset,
   cmd->cnc = cnc;
   recset->cmd = cmd;
   rc = SQLAllocStmt(cnc->hdbc, &recset->hstmt);
-  if (rc == SQL_ERROR)
-    return 0;
+  fprintf(stderr,"schema_tables: Step1: cnc = %p, cnc->hdbc = %p, recset->hstmt = %p\n", cnc, cnc->hdbc, recset->hstmt);
+  if (rc != SQL_SUCCESS)
+    {
+      fprintf(stderr,"SQLAllocSrmr failed\n");
+      return 0;
+    }
   rc = SQLTables(recset->hstmt,
 		 "", SQL_NTS,
 		 "", SQL_NTS,
 		 "", SQL_NTS,
 		 "", SQL_NTS);
-  if (rc == SQL_ERROR)
+  if (rc != SQL_SUCCESS)
     {
+      fprintf(stderr,"schema_tables: Step2: cnc = %p, cnc->hdbc = %p\n", cnc, cnc->hdbc);
       gda_odbc_error_make(gda_odbc_error_new(),
 			  recset,
 			  cnc,
@@ -131,8 +136,10 @@ schema_columns(Gda_ODBC_Recordset*  recset,
   cmd->cnc = cnc;
   recset->cmd = cmd;
   rc = SQLAllocStmt(cnc->hdbc, &recset->hstmt);
-  if (rc == SQL_ERROR)
-    return 0;
+  if (rc != SQL_SUCCESS)
+    {
+      return 0;
+    }
   ptr = constraints;
   while(length)
     {
@@ -174,7 +181,7 @@ schema_columns(Gda_ODBC_Recordset*  recset,
       SQLFreeStmt(recset->hstmt, SQL_DROP);
       return 0;
     }
-  fprintf(stderr,"schema_columns: calling gda_init_recset_for_hstmt\n");
+  fprintf(stderr,"schema_columns: calling gda_odbc_init_recset_for_hstmt\n");
   return gda_odbc_init_recset_for_hstmt(recset, e);
 }
 
@@ -235,7 +242,8 @@ gda_odbc_connection_open(Gda_ODBC_Connection* cnc,
 			 const gchar*               passwd)
 {
   int rc;
-  
+
+  fprintf(stderr,"gda_odbc_connection_open: enter\n");
   rc = SQLAllocEnv(&cnc->henv);
   if (rc != SQL_SUCCESS)
     return -1;
@@ -253,9 +261,15 @@ gda_odbc_connection_open(Gda_ODBC_Connection* cnc,
 		  (char*)passwd, SQL_NTS);
   if (rc != SQL_SUCCESS)
     {
+      gda_odbc_error_make(gda_odbc_error_new(),
+			  0,
+			  cnc,
+			  "SQLConnect");
       SQLFreeEnv(cnc->henv);
       SQLFreeConnect(cnc->hdbc);
+      return -1;
     }
+  fprintf(stderr,"gda_odbc_connection_open: left\n");
   return 0;
 }
 
@@ -270,8 +284,6 @@ gda_odbc_connection_open_schema(Gda_ODBC_Connection*      cnc,
   Gda_ODBC_Recordset* rc = gda_odbc_recset_new();
   schema_ops_fn       fn = schema_ops[t];
 
-  cnc->recsets = g_list_append(cnc->recsets, rc);
-  
   if (fn)
     {
       return fn(rc, e, cnc, constraints, length);
@@ -280,7 +292,6 @@ gda_odbc_connection_open_schema(Gda_ODBC_Connection*      cnc,
     {
       g_log("GDA ODBC", G_LOG_LEVEL_INFO,"schema_open_schema: Unhandled SCHEMA_QTYPE %d\n", t);
     }
-  g_list_remove(cnc->recsets, rc);
   gda_odbc_recset_free(rc);
   return 0;
 }
@@ -290,11 +301,6 @@ gda_odbc_connection_open_schema(Gda_ODBC_Connection*      cnc,
 gint
 gda_odbc_connection_close(Gda_ODBC_Connection* cnc)
 {
-  while (cnc->recsets)
-    {
-      gda_odbc_recset_close(cnc->recsets->data);
-      cnc->recsets = g_list_remove_link(cnc->recsets, cnc->recsets);
-    }
   while (cnc->commands)
     {
       gda_odbc_cmd_set_connection(cnc->commands->data, 0);
