@@ -63,7 +63,6 @@ gda_ConnectionFactory_create(PortableServer_Servant _obj,
   return new_connection;
 }
 
-
 CORBA_long
 gda_Connection_open(PortableServer_Servant _obj,
 		    const CORBA_char*            dsn,
@@ -73,10 +72,63 @@ gda_Connection_open(PortableServer_Servant _obj,
 {
   GDAConnection_Servant* cnc = (GDAConnection_Servant*) _obj;
 
+  fprintf(stderr,"gda_Connection_open enter\n");
   if (gda_odbc_connection_open(cnc->cnc, dsn, user, passwd) < 0)
-    return -1;
+    {
+      fprintf(stderr,"gda_Connection_open Errr left\n");
+      return -1;
+    }
   else
+    {
+      fprintf(stderr,"gda_Connection_open OK left\n");
+      return 0;
+    }
+}
+
+CORBA_long
+GDA_odbc_begin_transaction (PortableServer_Servant _obj, CORBA_Environment* ev)
+{
+  GDAConnection_Servant* cnc_servant = (GDAConnection_Servant*)_obj;
+  Gda_ODBC_Connection*   cnc = cnc_servant->cnc;
+  GDA_NotSupported*      exception;
+  
+  if (SQLSetConnectOption(cnc->hdbc, SQL_AUTOCOMMIT, SQL_AUTOCOMMIT_OFF) == SQL_SUCCESS)
     return 0;
+  exception = GDA_NotSupported__alloc();
+  exception->errormsg = CORBA_string_dup("Transactions not Supported");
+  CORBA_exception_set(ev, CORBA_USER_EXCEPTION, ex_GDA_NotSupported, exception);
+  return -1;
+}
+
+
+CORBA_long
+GDA_odbc_commit_transaction (PortableServer_Servant _obj, CORBA_Environment* ev)
+{
+  GDAConnection_Servant* cnc_servant = (GDAConnection_Servant*)_obj;
+  Gda_ODBC_Connection*   cnc = cnc_servant->cnc;
+  GDA_NotSupported*      exception;
+  
+  if (SQLTransact(cnc->henv, cnc->hdbc, SQL_COMMIT) == SQL_SUCCESS)
+    return 0;
+  exception = GDA_NotSupported__alloc();
+  exception->errormsg = CORBA_string_dup("Transactions not Supported");
+  CORBA_exception_set(ev, CORBA_USER_EXCEPTION, ex_GDA_NotSupported, exception);
+  return -1;
+}
+
+CORBA_long
+GDA_odbc_rollback_transaction (PortableServer_Servant _obj, CORBA_Environment* ev)
+{
+  GDAConnection_Servant* cnc_servant = (GDAConnection_Servant*)_obj;
+  Gda_ODBC_Connection*   cnc         = cnc_servant->cnc;
+  GDA_NotSupported*      exception;
+  
+  if (SQLTransact(cnc->henv, cnc->hdbc, SQL_ROLLBACK) == SQL_SUCCESS)
+    return 0;
+  exception = GDA_NotSupported__alloc();
+  exception->errormsg = CORBA_string_dup("Transactions not Supported");
+  CORBA_exception_set(ev, CORBA_USER_EXCEPTION, ex_GDA_NotSupported, exception);
+  return -1;
 }
 
 GDA_Recordset
@@ -95,7 +147,14 @@ gda_Connection_openSchema   (PortableServer_Servant _obj,
   fprintf(stderr,"gda_Connection_openSchema: constraints->_maximum = %d\n", constraints->_maximum);
   memset(&e, '\0', sizeof(e));
   if ((recset = gda_odbc_connection_open_schema(cnc->cnc, &e, t, constraints->_buffer, constraints->_length)) == 0)
-    return CORBA_OBJECT_NIL;
+    {
+      gchar bfr[128];
+      GDA_NotSupported* exception = GDA_NotSupported__alloc();
+      g_snprintf(bfr, sizeof(bfr), "SCHEMA type %d not supported\n", t);
+      exception->errormsg = CORBA_string_dup(bfr);
+      CORBA_exception_set(ev, CORBA_USER_EXCEPTION, ex_GDA_NotSupported, exception);
+      return CORBA_OBJECT_NIL;
+    }
   new_recset_servant = g_new0(GDARecordset_Servant, 1);
   new_recset_servant->base._private = 0;
   new_recset_servant->base.vepv = &poa_gda_recordset__vepv;
@@ -119,11 +178,15 @@ gda_Connection_close(PortableServer_Servant _obj,
 		    CORBA_Environment*      env)
 {
   GDAConnection_Servant* cnc = (GDAConnection_Servant*) _obj;
-
+  PortableServer_POA     poa = cnc->poa;
+  
   if (gda_odbc_connection_close(cnc->cnc) < 0)
     return -1;
-  else
-    return 0;
+  PortableServer_POA_deactivate_object(poa,
+				       PortableServer_POA_servant_to_id(poa,cnc, env),
+				       env);
+  Exception(env);
+  return 0;
 }
 
 GDA_Command
@@ -216,8 +279,31 @@ gda_Command_execute(PortableServer_Servant _obj,
   return new_recset;
 }
 
+CORBA_long
+GDA_odbc_recset_close(PortableServer_Servant _obj,
+		      CORBA_Environment*      env)
+{
+  GDARecordset_Servant*  rs = (GDARecordset_Servant*) _obj;
+  PortableServer_POA     poa = rs->poa;
 
-static GDA_Recordset_Chunk*
+  fprintf(stderr,"GDA_odbc_recset_close: closing recordset\n");
+  if (gda_odbc_recset_close(rs->recset) < 0)
+    {
+      fprintf(stderr,"GDA_odbc_recset_close: error during close\n");
+      return -1;
+    }
+  fprintf(stderr,"GDA_odbc_recset_close: NOT deactivating object\n");
+#if 0
+  PortableServer_POA_deactivate_object(poa,
+				       PortableServer_POA_servant_to_id(poa,rs, env),
+				       env);
+  Exception(env);
+#endif
+  fprintf(stderr,"GDA_odbc_recset_close: left\n");
+  return 0;
+}
+
+GDA_Recordset_Chunk*
 gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environment* ev)
 {
 
@@ -333,12 +419,52 @@ gda_Recset_fetch(PortableServer_Servant _obj, CORBA_long count, CORBA_Environmen
   return chunk;
 }
 
+GDA_RowAttributes*
+gda_Recset_describe(PortableServer_Servant _obj, CORBA_Environment* ev)
+{
+  GDARecordset_Servant*  recset_servant = (GDARecordset_Servant*)_obj;
+  Gda_ODBC_Recordset*    rs = recset_servant->recset;
+  GDA_RowAttributes*     rc;
+  GList*                 ptr;
+  Gda_ODBC_Field*        server_field;
+  GDA_FieldAttributes*   field;
+  gint                   idx;
+
+  fprintf(stderr,"gda_Recset_describe called\n");
+  
+  rc = GDA_RowAttributes__alloc();
+  rc->_length = g_list_length(rs->fields);
+  fprintf(stderr,"gda_Recset_describe: length = %d\n", rc->_length);
+  rc->_buffer = CORBA_sequence_GDA_FieldAttributes_allocbuf(rc->_length);
+  rc->_maximum = 0;
+
+  idx = 0;
+  ptr = rs->fields;
+  while (ptr)
+    {
+      field = &rc->_buffer[idx];
+      server_field = ptr->data;
+      
+      field->name        = CORBA_string_dup(server_field->name);
+      fprintf(stderr,"gda_Recset_describe: sending field description for '%s'\n", field->name);
+      field->definedSize = server_field->defined_length;
+      
+      field->scale       = server_field->num_scale;
+      field->gdaType     = gda_odbc_sql2gdatype(server_field->sql_type);
+      field->nativeType  = server_field->sql_type;
+      ptr = g_list_next(ptr);
+      idx++;
+    }
+  return rc;
+}
+  
 CORBA_Object
 connection_factory__create  (PortableServer_POA poa,   gpointer *impl_ptr,  CORBA_Environment *ev)
 {
   GDAConnectionFactory_Servant* servant;
   PortableServer_ObjectId *objid;
   CORBA_Object retval;
+
   servant = g_new0(GDAConnectionFactory_Servant, 1);
   servant->base._private = NULL;
   servant->base.vepv     = &poa_gda_connectionfactory__vepv;
