@@ -34,8 +34,8 @@
 Gda_ODBC_Recordset*
 gda_odbc_recset_new()
 {
-  Gda_ODBC_Recordset* rc = g_new(Gda_ODBC_Recordset, 1);
-  memset(rc, 0, sizeof(Gda_ODBC_Recordset));
+  Gda_ODBC_Recordset* rc = g_new0(Gda_ODBC_Recordset, 1);
+
   return rc;
 }
 
@@ -462,6 +462,7 @@ gda_odbc_recset_close(Gda_ODBC_Recordset* rec)
 {
   GList* ptr;
 
+  fprintf(stderr,"gda_odbc_recset_close: enter\n");
   if (rec->cmd && rec->auto_cmd)
     {
       gda_odbc_cmd_free(rec->cmd);
@@ -483,5 +484,6 @@ gda_odbc_recset_close(Gda_ODBC_Recordset* rec)
   g_list_free(rec->fields);
 
   rec->fields = 0;
+  fprintf(stderr,"gda_odbc_recset_close: left\n");
   return 0;
 }
